==> com.liferay.layout.content.page.editor.web-1.0.20.jar: META-INF/resources/js/components/floating_toolbar/image_properties/FloatingToolbarImagePropertiesPanel.es.js <==
"use strict";

Liferay.Loader.define("layout-content-page-editor-web@1.0.20/js/components/floating_toolbar/image_properties/FloatingToolbarImagePropertiesPanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './FloatingToolbarImagePropertiesPanelDelegateTemplate.soy', '../../../utils/constants', '../../../actions/saveChanges.es', '../../../store/ConnectedComponent.es', './FloatingToolbarImagePropertiesPanel.soy', '../../../actions/actions.es'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.default = exports.FloatingToolbarImagePropertiesPanel = exports.ConnectedFloatingToolbarImagePropertiesPanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireWildcard(require("frontend-js-metal-web$metal-soy"));

  require("./FloatingToolbarImagePropertiesPanelDelegateTemplate.soy");

  var _constants = require("../../../utils/constants");

  var _saveChanges = require("../../../actions/saveChanges.es");

  var _ConnectedComponent = _interopRequireDefault(require("../../../store/ConnectedComponent.es"));

  var _FloatingToolbarImagePropertiesPanel = _interopRequireDefault(require("./FloatingToolbarImagePropertiesPanel.soy"));

  var _actions = require("../../../actions/actions.es");

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj.default = obj;return newObj;
    }
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { default: obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarImagePropertiesPanel
   */
  var FloatingToolbarImagePropertiesPanel =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FloatingToolbarImagePropertiesPanel, _Component);

    function FloatingToolbarImagePropertiesPanel() {
      _classCallCheck(this, FloatingToolbarImagePropertiesPanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarImagePropertiesPanel).apply(this, arguments));
    }

    _createClass(FloatingToolbarImagePropertiesPanel, [{
      key: "_updateFragmentConfig",

      /**
       * Updates fragment configuration
       * @param {object} config Configuration
       * @private
       * @review
       */
      value: function _updateFragmentConfig(config) {
        this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)()).dispatch({
          config: config,
          editableId: this.item.editableId,
          fragmentEntryLinkId: this.item.fragmentEntryLinkId,
          type: _actions.UPDATE_CONFIG_ATTRIBUTES
        }).dispatch((0, _saveChanges.updateLastSaveDateAction)()).dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
      }
      /**
       * Handle select image button change
       * @private
       * @review
       */

    }, {
      key: "_handleClearImageButtonClick",
      value: function _handleClearImageButtonClick() {
        this.store.dispatch({
          itemId: this.itemId,
          type: _actions.CLEAR_FRAGMENT_EDITOR
        });
      }
      /**
       * Handle image link change
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleImageLinkInputChange",
      value: function _handleImageLinkInputChange(event) {
        this._updateFragmentConfig(_defineProperty({}, _constants.EDITABLE_FIELD_CONFIG_KEYS.imageLink, event.delegateTarget.value));
      }
      /**
       * Handle image target option change
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleImageTargetOptionChange",
      value: function _handleImageTargetOptionChange(event) {
        this._updateFragmentConfig(_defineProperty({}, _constants.EDITABLE_FIELD_CONFIG_KEYS.imageTarget, event.delegateTarget.value));
      }
      /**
       * Handle select image button change
       * @private
       * @review
       */

    }, {
      key: "_handleSelectImageButtonClick",
      value: function _handleSelectImageButtonClick() {
        this.store.dispatch({
          itemId: this.itemId,
          type: _actions.ENABLE_FRAGMENT_EDITOR
        });
      }
    }]);

    return FloatingToolbarImagePropertiesPanel;
  }(_metalComponent.default);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarImagePropertiesPanel = FloatingToolbarImagePropertiesPanel;
  FloatingToolbarImagePropertiesPanel.STATE = {
    /**
     * @default TARGET_TYPES
     * @memberOf FloatingToolbarImagePropertiesPanel
     * @private
     * @review
     * @type {object[]}
     */
    _imageTargetOptions: _metalSoy.Config.array().internal().value(_constants.TARGET_TYPES),

    /**
     * @default undefined
     * @memberOf FloatingToolbarImagePropertiesPanel
     * @review
     * @type {object}
     */
    item: _metalSoy.Config.object(),

    /**
     * @default undefined
     * @memberof FloatingToolbarImagePropertiesPanel
     * @review
     * @type {!string}
     */
    itemId: _metalSoy.Config.string().required(),

    /**
     * @default undefined
     * @memberof FloatingToolbarImagePropertiesPanel
     * @review
     * @type {object}
     */
    store: _metalSoy.Config.object().value(null)
  };
  var ConnectedFloatingToolbarImagePropertiesPanel = (0, _ConnectedComponent.default)(FloatingToolbarImagePropertiesPanel, ['imageSelectorURL', 'portletNamespace']);
  exports.ConnectedFloatingToolbarImagePropertiesPanel = ConnectedFloatingToolbarImagePropertiesPanel;

  _metalSoy.default.register(ConnectedFloatingToolbarImagePropertiesPanel, _FloatingToolbarImagePropertiesPanel.default);

  var _default = FloatingToolbarImagePropertiesPanel;
  exports.default = _default;
  //# sourceMappingURL=FloatingToolbarImagePropertiesPanel.es.js.map
});
//# sourceMappingURL=FloatingToolbarImagePropertiesPanel.es.js.map

==> com.liferay.layout.content.page.editor.web-1.0.52.jar: META-INF/resources/js/components/floating_toolbar/image_properties/FloatingToolbarImagePropertiesPanel.es.js <==
Liferay.Loader.define("layout-content-page-editor-web@1.0.52/js/components/floating_toolbar/image_properties/FloatingToolbarImagePropertiesPanel.es", ['module', 'exports', 'require', 'frontend-js-metal-web$metal-component', 'frontend-js-metal-web$metal-soy', './FloatingToolbarImagePropertiesPanelDelegateTemplate.soy', '../../../actions/actions.es', '../../../actions/saveChanges.es', '../../../store/ConnectedComponent.es', '../../../utils/constants', './FloatingToolbarImagePropertiesPanel.soy'], function (module, exports, require) {
  var define = undefined;
  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.FloatingToolbarImagePropertiesPanel = exports.ConnectedFloatingToolbarImagePropertiesPanel = void 0;

  var _metalComponent = _interopRequireDefault(require("frontend-js-metal-web$metal-component"));

  var _metalSoy = _interopRequireWildcard(require("frontend-js-metal-web$metal-soy"));

  require("./FloatingToolbarImagePropertiesPanelDelegateTemplate.soy");

  var _actions = require("../../../actions/actions.es");

  var _saveChanges = require("../../../actions/saveChanges.es");

  var _ConnectedComponent = _interopRequireDefault(require("../../../store/ConnectedComponent.es"));

  var _constants = require("../../../utils/constants");

  var _FloatingToolbarImagePropertiesPanel = _interopRequireDefault(require("./FloatingToolbarImagePropertiesPanel.soy"));

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    } else {
      var newObj = {};if (obj != null) {
        for (var key in obj) {
          if (Object.prototype.hasOwnProperty.call(obj, key)) {
            var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {};if (desc.get || desc.set) {
              Object.defineProperty(newObj, key, desc);
            } else {
              newObj[key] = obj[key];
            }
          }
        }
      }newObj["default"] = obj;return newObj;
    }
  }

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _typeof(obj) {
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }

  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
    }
  }

  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
  }

  function _possibleConstructorReturn(self, call) {
    if (call && (_typeof(call) === "object" || typeof call === "function")) {
      return call;
    }return _assertThisInitialized(self);
  }

  function _assertThisInitialized(self) {
    if (self === void 0) {
      throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
    }return self;
  }

  function _getPrototypeOf(o) {
    _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
      return o.__proto__ || Object.getPrototypeOf(o);
    };return _getPrototypeOf(o);
  }

  function _inherits(subClass, superClass) {
    if (typeof superClass !== "function" && superClass !== null) {
      throw new TypeError("Super expression must either be null or a function");
    }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
  }

  function _setPrototypeOf(o, p) {
    _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
      o.__proto__ = p;return o;
    };return _setPrototypeOf(o, p);
  }

  /**
   * FloatingToolbarImagePropertiesPanel
   */
  var FloatingToolbarImagePropertiesPanel =
  /*#__PURE__*/
  function (_Component) {
    _inherits(FloatingToolbarImagePropertiesPanel, _Component);

    function FloatingToolbarImagePropertiesPanel() {
      _classCallCheck(this, FloatingToolbarImagePropertiesPanel);

      return _possibleConstructorReturn(this, _getPrototypeOf(FloatingToolbarImagePropertiesPanel).apply(this, arguments));
    }

    _createClass(FloatingToolbarImagePropertiesPanel, [{
      key: "_updateFragmentConfig",

      /**
       * Updates fragment configuration
       * @param {object} config Configuration
       * @private
       * @review
       */
      value: function _updateFragmentConfig(config) {
        this.store.dispatch((0, _saveChanges.enableSavingChangesStatusAction)()).dispatch({
          config: config,
          editableId: this.item.editableId,
          fragmentEntryLinkId: this.item.fragmentEntryLinkId,
          type: _actions.UPDATE_CONFIG_ATTRIBUTES
        }).dispatch((0, _saveChanges.updateLastSaveDateAction)()).dispatch((0, _saveChanges.disableSavingChangesStatusAction)());
      }
      /**
       * Handle alt text change
       * @private
       * @review
       */

    }, {
      key: "_handleAltTextInputChange",
      value: function _handleAltTextInputChange() {
        this._updateFragmentConfig(_defineProperty({}, _constants.EDITABLE_FIELD_CONFIG_KEYS.alt, window.event.delegateTarget.value));
      }
      /**
       * Handle select image button change
       * @private
       * @review
       */

    }, {
      key: "_handleClearImageButtonClick",
      value: function _handleClearImageButtonClick() {
        this.emit('clearEditor');
      }
      /**
       * Handle image link change
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleImageLinkInputChange",
      value: function _handleImageLinkInputChange(event) {
        this._updateFragmentConfig(_defineProperty({}, _constants.EDITABLE_FIELD_CONFIG_KEYS.imageLink, event.delegateTarget.value));
      }
      /**
       * Handle image target option change
       * @param {Event} event
       * @private
       * @review
       */

    }, {
      key: "_handleImageTargetOptionChange",
      value: function _handleImageTargetOptionChange(event) {
        this._updateFragmentConfig(_defineProperty({}, _constants.EDITABLE_FIELD_CONFIG_KEYS.imageTarget, event.delegateTarget.value));
      }
      /**
       * Handle select image button change
       * @private
       * @review
       */

    }, {
      key: "_handleSelectImageButtonClick",
      value: function _handleSelectImageButtonClick() {
        this.emit('createProcessor');
      }
    }]);

    return FloatingToolbarImagePropertiesPanel;
  }(_metalComponent["default"]);
  /**
   * State definition.
   * @review
   * @static
   * @type {!Object}
   */

  exports.FloatingToolbarImagePropertiesPanel = FloatingToolbarImagePropertiesPanel;
  FloatingToolbarImagePropertiesPanel.STATE = {
    /**
     * @default TARGET_TYPES
     * @memberOf FloatingToolbarImagePropertiesPanel
     * @private
     * @review
     * @type {object[]}
     */
    _imageTargetOptions: _metalSoy.Config.array().internal().value(_constants.TARGET_TYPES),

    /**
     * @default undefined
     * @memberOf FloatingToolbarImagePropertiesPanel
     * @review
     * @type {object}
     */
    item: _metalSoy.Config.object(),

    /**
     * @default undefined
     * @memberof FloatingToolbarImagePropertiesPanel
     * @review
     * @type {!string}
     */
    itemId: _metalSoy.Config.string().required(),

    /**
     * @default undefined
     * @memberof FloatingToolbarImagePropertiesPanel
     * @review
     * @type {object}
     */
    store: _metalSoy.Config.object().value(null)
  };
  var ConnectedFloatingToolbarImagePropertiesPanel = (0, _ConnectedComponent["default"])(FloatingToolbarImagePropertiesPanel, ['imageSelectorURL', 'portletNamespace']);
  exports.ConnectedFloatingToolbarImagePropertiesPanel = ConnectedFloatingToolbarImagePropertiesPanel;

  _metalSoy["default"].register(ConnectedFloatingToolbarImagePropertiesPanel, _FloatingToolbarImagePropertiesPanel["default"]);

  var _default = FloatingToolbarImagePropertiesPanel;
  exports["default"] = _default;
  //# sourceMappingURL=FloatingToolbarImagePropertiesPanel.es.js.map
});
//# sourceMappingURL=FloatingToolbarImagePropertiesPanel.es.js.map
